# Extract Sphinx RST Files

## Install
This installs the most recent testing version of xrst:

    pip install xrst
    pip uninstall -y xrst
    pip install --index-url https://test.pypi.org/simple/ xrst


## Documentation
https://xrst.readthedocs.io

## Git Repository
https://github.com/bradbell/xrst
